[Libreoffice-commits] core.git: sdext/source

Dominique Leuenberger dimstar at suse.de
Mon Jan 8 15:07:35 UTC 2018


 sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx |   10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

New commits:
commit 38368be8527ca655854ee1231d9f355b8c0591ec
Author: Dominique Leuenberger <dimstar at suse.de>
Date:   Fri Jan 5 12:16:03 2018 +0100

    Allow building with poppler-0.62
    
    Change-Id: Ia627f1628a67dd8ece7d9318639d9ccd06b89765
    Reviewed-on: https://gerrit.libreoffice.org/47460
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Michael Stahl <mstahl at redhat.com>

diff --git a/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx b/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
index 85647b6a3c22..4f6ff1d49b33 100644
--- a/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
+++ b/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
@@ -32,10 +32,12 @@
 #pragma warning(push, 1)
 #endif
 
 // sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
 // FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
 //        because the internal poppler does not provide poppler-version.h and the macro always returns 0
-#if POPPLER_CHECK_VERSION(0, 21, 1)
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+#include <UnicodeMapFuncs.h>
+#elif POPPLER_CHECK_VERSION(0, 21, 1)
 #include <UTF8.h>
 #elif POPPLER_CHECK_VERSION(0, 21, 0)
 #include "UTF.h"
@@ -913,7 +915,11 @@ void PDFOutDev::drawChar(GfxState *state, double x, double y,
             );
 
     // silence spurious warning
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+    (void)&mapUTF16;
+#else
     (void)&mapUCS2;
+#endif
 
     char buf[9];
     for( int i=0; i<uLen; ++i )
@@ -32,10 +32,12 @@
 #endif
 
-// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
+// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1, then renamed to UnicodeMapFuncs.h in 0.62.0
 // FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
 //        because the internal poppler does not provide poppler-version.h and the macro always returns 0


More information about the Libreoffice-commits mailing list